@@ -133,6 +133,39 @@ remove_duplicated_states.intern <- function(data, keep.last = TRUE) {
     indToKeep <- c(indToKeep, nrow(data))
   }
 
-
   return(data[indToKeep, ])
 }
+
+
+melt2cfd <- function(X, times = NULL, byrow = FALSE) {
+  nTimes <- ifelse(byrow, ncol(X), nrow(X))
+  nInd <- ifelse(byrow, nrow(X), ncol(X))
+
+  if (byrow) {
+    X <- t(X)
+  }
+
+  if (is.null(times)) {
+    times <- seq_len(nTimes)
+  }
+
+  outData <- data.frame(id = c(), time = c(), state = c())
+
+  for (ind in seq_len(nInd))
+  {
+    outData <- rbind(outData, data.frame(id = ind, time = times[1], state = labels[X[1, ind] + 1]))
+    if (nTimes > 2)
+    {
+      # do not copy 2 consecutive time values with the same state
+      for (time in 2:(nTimes - 1))
+      {
+        if (X[time, ind] != X[time - 1, ind]) {
+          outData <- rbind(outData, data.frame(id = ind, time = times[time], state = labels[X[time, ind] + 1]))
+        }
+      }
+    }
+    outData <- rbind(outData, data.frame(id = ind, time = times[nTimes], state = labels[X[nTimes, ind] + 1]))
+  }
+
+  return(outData)
+}
